# -*- coding: utf-8 -*-
# @Project: 芒果测试平台
# @Description: 
# @Time   : 2024-02-04 10:43
# @Author : 毛鹏
from typing import Optional
from unittest.mock import MagicMock

import sys
from uiautomator2 import Device

from mangoautomation.enums import DriveTypeEnum
from mangoautomation.exceptions import MangoAutomationError
from mangoautomation.exceptions._error_msg import ERROR_MSG_0010, ERROR_MSG_0007
from mangotools.data_processor import DataProcessor
from mangotools.database import MysqlConnect
from mangotools.enums import StatusEnum
from mangotools.models import MysqlConingModel

if not sys.platform.startswith('win32'):
    WindowControl = MagicMock()
    print("警告: uiautomation 仅支持 Windows，当前环境已自动跳过")
else:
    from uiautomation import WindowControl


class BaseData:

    def __init__(self, test_data: DataProcessor, log):
        super().__init__()
        self.test_data = test_data
        self.log = log
        self.download_path: Optional[str | None] = None
        self.screenshot_path: Optional[str | None] = None

        self.mysql_config: Optional[MysqlConingModel | None] = None
        self.mysql_connect: Optional[MysqlConnect | None] = None

        self.url: Optional[str | None] = None
        self.is_open_url = False
        self.page = None
        self.context = None

        self.package_name: Optional[str | None] = None
        self.android: Optional[Device | None] = None
        self.is_open_app = False

        self.window: Optional[None | WindowControl] = None

    def set_file_path(self, download_path, screenshot_path):
        self.download_path = download_path
        self.screenshot_path = screenshot_path
        return self

    def set_url(self, url: str):
        self.url = url
        return self

    def set_page_context(self, page, context):
        self.page = page
        self.context = context
        return self

    def set_package_name(self, package_name: str):
        self.package_name = package_name
        return self

    def set_android(self, android: Device):
        self.android = android
        return self

    def setup(self) -> None:
        self.url = None
        self.page = None
        self.context = None

        self.package_name = None
        self.android = None
        self.mysql_connect = None
        self.mysql_config = None

    async def async_base_close(self):
        if self.context:
            await self.context.close()
        if self.page:
            await self.page.close()
        if self.mysql_connect:
            self.mysql_connect.close()
        self.setup()

    def sync_base_close(self):
        if self.context:
            self.context.close()
        if self.page:
            self.page.close()
        if self.mysql_connect:
            self.mysql_connect.close()
        self.setup()

    def set_mysql(self, db_c_status, db_rud_status, mysql_config: MysqlConingModel):
        self.mysql_config = mysql_config
        if StatusEnum.SUCCESS.value in [db_c_status, db_rud_status]:
            self.mysql_connect = MysqlConnect(mysql_config,
                                              bool(db_c_status),
                                              bool(db_rud_status))
        return self

    def verify_equipment(self, drive_type: int):
        if drive_type == DriveTypeEnum.WEB.value:
            if not self.page or not self.context:
                raise MangoAutomationError(*ERROR_MSG_0010)
        elif drive_type == DriveTypeEnum.ANDROID.value:
            if not self.android:
                raise MangoAutomationError(*ERROR_MSG_0007)
        else:
            pass



# -*- coding: utf-8 -*-
# @Project: 芒果测试平台
# @Description:
# @Time   : 2023-05-28 18:40
# @Author : 毛鹏

from pydantic import BaseModel

from mangotools.models import MysqlConingModel, MethodModel


class EnvironmentConfigModel(BaseModel):
    id: int
    test_object_value: str
    db_c_status: bool
    db_rud_status: bool
    mysql_config: MysqlConingModel | None = None


class ElementModel(BaseModel):
    id: int
    type: int
    name: str | None
    loc: str | None
    exp: int | None
    sleep: int | None
    sub: int | None
    is_iframe: int | None
    ope_key: str | None
    ope_value: list[MethodModel] | None
    key_list: list | None = None
    sql: str | None = None
    key: str | None = None
    value: str | None = None


class ElementResultModel(BaseModel):
    id: int
    name: str | None = None
    loc: str | None = None
    exp: int | None = None
    sleep: int | None = None
    sub: int | None = None

    type: int
    ope_key: str | None = None
    ope_value: dict = {}
    ass_msg: str | None = None
    sql: str | None = None
    key_list: str | None = None
    key: str | None = None
    value: str | None = None

    ele_quantity: int = 0
    element_text: str | None = None

    status: int = 0
    error_message: str | None = None
    picture_path: str | None = None
    picture_name: str | None = None



# -*- coding: utf-8 -*-
# @Project: 芒果测试平台
# @Description: # @Time   : 2023-04-26 22:22
# @Author : 毛鹏

from ....tools import Meta
from ....uidrive._base_data import BaseData


class SyncWebCustomization(metaclass=Meta):
    """定制开发"""

    def __init__(self, base_data: BaseData):
        self.base_data = base_data



# -*- coding: utf-8 -*-
# @Project: 芒果测试平台
# @Description: 
# @Time   : 2023-04-29 11:23
# @Author : 毛鹏
import sys

from ..enums._ui_enum import ElementExpEnum, ElementOperationEnum, DeviceEnum, BrowserTypeEnum, DriveTypeEnum

python_version = sys.version_info
if f"{python_version.major}.{python_version.minor}" != "3.10":
    raise Exception("必须使用>Python3.10.4")
__all__ = [
    'ElementOperationEnum',
    'DeviceEnum',
    'BrowserTypeEnum',
    'DriveTypeEnum',
    'ElementExpEnum',
]



# -*- coding: utf-8 -*-
# @Project: 芒果测试平台
# @Description:
# @Time   : 2023-09-09 23:17
# @Author : 毛鹏
from uiautomator2 import UiObject

from mangoautomation.tools import Meta
from mangoautomation.uidrive._base_data import BaseData
from mangotools.decorator import sync_method_callback
from mangotools.models import MethodModel


class AndroidAssertion(metaclass=Meta):
    """元素断言"""

    def __init__(self, base_data: BaseData):
        self.base_data = base_data

    @sync_method_callback('ass_android', '元素断言', 1, [
        MethodModel(f='actual')])
    def a_assert_ele_exists(self, actual: UiObject):
        """元素存在"""
        assert actual.count, f'实际={actual.count}, 预期=元素存在'
        return f'实际={actual.count}, 预期=元素存在'

    @sync_method_callback('ass_android', '元素断言', 2, [
        MethodModel(f='actual'),
        MethodModel(f='expect', p='请输入预期内容', d=True)])
    def a_assert_ele_count(self, actual: UiObject, expect):
        """元素计数"""
        assert int(actual.count) == int(expect), f'实际={actual.count}, 预期={expect}'
        return f'实际={actual.count}, 预期={expect}'

    @sync_method_callback('ass_android', '元素断言', 3, [
        MethodModel(f='actual'),
        MethodModel(f='expect', p='请输入预期文本', d=True)])
    def a_assert_ele_text(self, actual: UiObject, expect: str):
        """元素文本内容"""
        assert actual.get_text() == expect, f"实际='{actual.get_text()}', 预期='{expect}'"
        return f'实际={actual.get_text()}, 预期={expect}'

    @sync_method_callback('ass_android', '元素断言', 4, [
        MethodModel(f='actual')])
    def a_assert_ele_clickable_true(self, actual: UiObject):
        """元素可点击"""
        assert actual.info['clickable'], f"实际={actual.info['clickable']}, 预期=可点击"
        return f"实际={actual.info['clickable']}, 预期=可点击"

    @sync_method_callback('ass_android', '元素断言', 5, [
        MethodModel(f='actual')])
    def a_assert_ele_clickable_false(self, actual: UiObject):
        """元素不可点击"""
        assert not actual.info['clickable'], f"实际={actual.info['clickable']}, 预期=元素不可点击"
        return f"实际={actual.info['clickable']}, 预期=元素不可点击"

    @sync_method_callback('ass_android', '元素断言', 6, [
        MethodModel(f='actual')])
    def a_assert_ele_visible_true(self, actual: UiObject):
        """元素可见"""
        assert actual.exists and actual.info['visible'], f"实际={actual.info['visible']}, 预期=元素可见"

        return f"实际={actual.info['visible']}, 预期=元素可见"

    @sync_method_callback('ass_android', '元素断言', 7, [
        MethodModel(f='actual')])
    def a_assert_ele_visible_false(self, actual: UiObject):
        """元素不可见"""
        assert actual.exists and not actual.info['visible'], f"实际={actual.info['visible']}, 预期=元素不可见"
        return f"实际={actual.info['visible']}, 预期=元素不可见"

    @sync_method_callback('ass_android', '元素断言', 8, [
        MethodModel(f='expect', p='请输入弹窗标题文本', d=False)])
    def a_assert_dialog_exists(self, expect: str):
        """弹窗存在"""
        dialog = self.base_data.android(text=expect) if expect else self.base_data.android(
            className="android.app.AlertDialog")
        assert dialog.exists, "未找到预期弹窗"
        return f"实际={dialog.exists}, 预期=弹窗存在"

    @sync_method_callback('ass_android', '元素断言', 9, [
        MethodModel(f='actual'),
        MethodModel(f='expect', p='请输入断言目标文本', d=True)])
    def a_assert_ele_in_list(self, actual: UiObject, expect: str):
        """列表滑动后目标元素存在"""
        if not actual.exists:
            raise AssertionError("传入的元素不是可滑动的列表")
        actual.scroll.vert.to(text=expect)
        assert self.base_data.android(text=expect).exists, f"列表中未找到文本: {expect}"
        return f"实际={self.base_data.android(text=expect).exists}, 预期={expect}"



# -*- coding: utf-8 -*-
# @Project: 芒果测试平台
# @Description:
# @Time   : 03-09-09 3:17
# @Author : 毛鹏
from time import sleep

from mangotools.decorator import sync_method_callback
from mangotools.models import MethodModel
from ...tools import Meta
from ...uidrive._base_data import BaseData


class AndroidEquipment(metaclass=Meta):
    """设备操作"""

    def __init__(self, base_data: BaseData):
        self.base_data = base_data

    @sync_method_callback('android', '设备操作', 1, [
        MethodModel(f='_time', p='请输入等待时间', d=True)])
    def a_sleep(self, time_: int):
        """强制等待"""
        sleep(time_)

    @sync_method_callback('android', '设备操作', 2)
    def a_screen_on(self):
        """打开屏幕"""
        self.base_data.android.screen_on()
        self.a_sleep(1)

    @sync_method_callback('android', '设备操作', 3)
    def a_screen_off(self):
        """关闭屏幕"""
        self.base_data.android.screen_off()
        self.a_sleep(1)

    @sync_method_callback('android', '设备操作', 4)
    def a_swipe_left(self):
        """获取屏幕开关状态"""
        self.base_data.android.info.get('screenOn')

    @sync_method_callback('android', '设备操作', 5)
    def a_get_window_size(self):
        """提取屏幕尺寸"""
        w, h = self.base_data.android.window_size()
        return w, h

    @sync_method_callback('android', '设备操作', 6, [
        MethodModel(f='feli_path', p='请输入计算机文件路径', d=True),
        MethodModel(f='catalogue', p='请输入设备目录', d=True)])
    def a_push(self, feli_path, catalogue):
        """推送一个文件到设备"""
        self.base_data.android.push(feli_path, catalogue)

    @sync_method_callback('android', '设备操作', 7, [
        MethodModel(f='feli_path', p='请输入设备文件路径', d=True),
        MethodModel(f='catalogue', p='请输入计算机目录', d=True)])
    def a_pull(self, feli_path, catalogue):
        """提取文件"""
        self.base_data.android.pull(feli_path, catalogue)

    @sync_method_callback('android', '设备操作', 8)
    def a_unlock(self):
        """解锁屏幕"""
        self.base_data.android.unlock()

    @sync_method_callback('android', '设备操作', 9)
    def a_press_home(self):
        """按home键"""
        self.base_data.android.press('home')

    @sync_method_callback('android', '设备操作', 10)
    def a_press_back(self):
        """按back键"""
        self.base_data.android.press('back')

    @sync_method_callback('android', '设备操作', 11)
    def a_press_left(self):
        """按left键"""
        self.base_data.android.press('left')

    @sync_method_callback('android', '设备操作', 12)
    def a_press_right(self):
        """按right键"""
        self.base_data.android.press('right')

    @sync_method_callback('android', '设备操作', 13)
    def a_press_up(self):
        """按up键"""
        self.base_data.android.press('up')

    @sync_method_callback('android', '设备操作', 14)
    def a_press_down(self):
        """按down键"""
        self.base_data.android.press('down')

    @sync_method_callback('android', '设备操作', 15)
    def a_press_center(self):
        """按center键"""
        self.base_data.android.press('center')

    @sync_method_callback('android', '设备操作', 16)
    def a_press_menu(self):
        """按menu键"""
        self.base_data.android.press('menu')

    @sync_method_callback('android', '设备操作', 17)
    def a_press_search(self):
        """按search键"""
        self.base_data.android.press('search')

    @sync_method_callback('android', '设备操作', 18)
    def a_press_enter(self):
        """按enter键"""
        self.base_data.android.press('enter')

    @sync_method_callback('android', '设备操作', 19)
    def a_press_delete(self):
        """按delete键"""
        self.base_data.android.press('delete')

    @sync_method_callback('android', '设备操作', 20)
    def a_press_recent(self):
        """按recent键"""
        self.base_data.android.press('recent')

    @sync_method_callback('android', '设备操作', 21)
    def a_press_volume_up(self):
        """按volume_up键"""
        self.base_data.android.press('volume_up')

    @sync_method_callback('android', '设备操作', 22)
    def a_press_volume_down(self):
        """按volume_down键"""
        self.base_data.android.press('volume_down')

    @sync_method_callback('android', '设备操作', 23)
    def a_press_volume_mute(self):
        """按volume_mute键"""
        self.base_data.android.press('volume_mute')

    @sync_method_callback('android', '设备操作', 24)
    def a_press_camera(self):
        """按camera键"""
        self.base_data.android.press('camera')

    @sync_method_callback('android', '设备操作', 25)
    def a_press_power(self):
        """按power键"""
        self.base_data.android.press('power')



# -*- coding: utf-8 -*-
# @Project: 芒果测试平台
# @Description: 
# @Time   : 2025-04-04 21:42
# @Author : 毛鹏
import re
import traceback

from playwright._impl._errors import TimeoutError, Error
from playwright.sync_api._generated import Locator

from mangotools.assertion import MangoAssertion
from mangotools.enums import StatusEnum
from mangotools.mangos import Mango
from ....enums import ElementExpEnum
from ....exceptions import MangoAutomationError
from ....exceptions._error_msg import *
from ....uidrive._base_data import BaseData
from ....uidrive.web.sync_web._assertion import SyncWebAssertion
from ....uidrive.web.sync_web._browser import SyncWebBrowser
from ....uidrive.web.sync_web._customization import SyncWebCustomization
from ....uidrive.web.sync_web._element import SyncWebElement
from ....uidrive.web.sync_web._input_device import SyncWebDeviceInput
from ....uidrive.web.sync_web._page import SyncWebPage

re = re
__all__ = [
    'SyncWebAssertion',
    'SyncWebBrowser',
    'SyncWebCustomization',
    'SyncWebDeviceInput',
    'SyncWebElement',
    'SyncWebPage',
    'SyncWebDevice',
]


class SyncWebDevice(SyncWebBrowser,
                    SyncWebPage,
                    SyncWebElement,
                    SyncWebDeviceInput,
                    SyncWebCustomization):

    def __init__(self, base_data: BaseData):
        super().__init__(base_data)

    def open_url(self, is_open: bool = False):
        if not self.base_data.is_open_url or is_open:
            self.base_data.log.debug(f'打开url，is_open_url：{self.base_data.is_open_url},url:{self.base_data.url}')
            self.w_goto(self.base_data.url)
            self.base_data.is_open_url = True

    def web_action_element(self, name, ope_key, ope_value, ):
        self.base_data.log.debug(f'操作元素，名称：{name},key:{ope_key},value:{ope_value}')
        try:
            Mango.s_e(self, ope_key, ope_value)
        except TimeoutError as error:
            self.base_data.log.error(f'WEB自动化操作失败-1，类型：{type(error)}，失败详情：{error}')
            raise MangoAutomationError(*ERROR_MSG_0011, value=(name,))
        except Error as error:
            self.base_data.log.error(f'WEB自动化操作失败-2，类型：{type(error)}，失败详情：{error}')
            raise MangoAutomationError(*ERROR_MSG_0032, value=(name,))
        except ValueError as error:
            self.base_data.log.error(f'WEB自动化操作失败-3，类型：{type(error)}，失败详情：{error}')
            raise MangoAutomationError(*ERROR_MSG_0012)

    def web_assertion_element(self, name, ope_key, ope_value) -> str:
        self.base_data.log.debug(f'断言元素，名称：{name},key:{ope_key},value:{ope_value}')
        is_method = callable(getattr(SyncWebAssertion, ope_key, None))
        try:
            if is_method:
                if ope_value.get('actual', None) is None:
                    raise MangoAutomationError(*ERROR_MSG_0031, value=(name,))
                self.base_data.log.debug(f'开始断言-1，方法：{ope_key}，断言值：{ope_value}')
                return Mango.s_e(SyncWebAssertion(self.base_data), ope_key, ope_value)
            else:
                self.base_data.log.debug(f'开始断言-2，方法：{ope_key}，断言值：{ope_value}')
                return MangoAssertion(self.base_data.mysql_connect) \
                    .ass(ope_key, ope_value.get('actual'), ope_value.get('expect'))
        except AssertionError as error:
            self.base_data.log.debug(f'WEB自动化断言失败-1，类型：{type(error)}，失败详情：{error}')
            raise MangoAutomationError(*ERROR_MSG_0017, value=error.args)
        except AttributeError as error:
            self.base_data.log.error(f'WEB自动化断言失败-2，类型：{type(error)}，失败详情：{error}')
            raise MangoAutomationError(*ERROR_MSG_0048)
        except ValueError as error:
            self.base_data.log.error(f'WEB自动化断言失败-3，类型：{type(error)}，失败详情：{error}')
            raise MangoAutomationError(*ERROR_MSG_0005)
        except Error as error:
            self.base_data.log.error(f'WEB自动化断言失败-4，类型：{type(error)}，失败详情：{error}')
            raise MangoAutomationError(*ERROR_MSG_0052, value=(name,), )

    def web_find_ele(self, name, _type, exp, loc, sub, is_iframe) \
            -> tuple[Locator, int, str] | tuple[list[Locator], int, str]:
        self.base_data.log.debug(
            f'查找元素，名称：{name},_type:{_type},exp:{exp},loc:{loc},sub:{sub},is_iframe:{is_iframe}')
        if is_iframe != StatusEnum.SUCCESS.value:
            locator: Locator = self.__find_ele(self.base_data.page, exp, loc)
            try:
                count = locator.count()
                loc = locator.nth(sub - 1) if sub else locator
                try:
                    text = self.w_get_text(loc)
                except Exception:
                    text = None
                return loc, count, text
            except Error as error:
                self.base_data.log.debug(
                    f'WEB自动化查找元素失败-1，类型：{type(error)}，失败详情：{error}，失败明细：{traceback.format_exc()}')
                raise MangoAutomationError(*ERROR_MSG_0041, )
        else:
            ele_list: list[Locator] = []
            for i in self.base_data.page.frames:
                locator: Locator = self.__find_ele(i, exp, loc)
                try:
                    count = locator.count()
                except Error as error:
                    self.base_data.log.debug(
                        f'WEB自动化查找元素失败-2，类型：{type(error)}，失败详情：{error}，失败明细：{traceback.format_exc()}')
                    raise MangoAutomationError(*ERROR_MSG_0041, )
                if count > 0:
                    for nth in range(0, count):
                        ele_list.append(locator.nth(nth))
                else:
                    raise MangoAutomationError(*ERROR_MSG_0023)

            try:
                count = len(ele_list)
                loc = ele_list[sub - 1] if sub else ele_list[0]
                try:
                    text = self.w_get_text(loc)
                except Exception:
                    text = None
                return loc, count, text
            except IndexError:
                raise MangoAutomationError(*ERROR_MSG_0025, value=(len(ele_list),))

    def __find_ele(self, page, exp, loc) -> Locator:
        match exp:
            case ElementExpEnum.LOCATOR.value:
                try:
                    return eval(f"page.{loc}")
                except SyntaxError:
                    try:
                        return eval(f"await page.{loc}")
                    except SyntaxError as error:
                        self.base_data.log.error(f'WEB自动化查找元素失败-3，类型：{type(error)}，失败详情：{error}')
                        raise MangoAutomationError(*ERROR_MSG_0022)
                    except NameError as error:
                        self.base_data.log.error(f'WEB自动化查找元素失败-4，类型：{type(error)}，失败详情：{error}')
                        raise MangoAutomationError(*ERROR_MSG_0060)
            case ElementExpEnum.XPATH.value:
                return page.locator(f'xpath={loc}')
            case ElementExpEnum.CSS.value:
                return page.locator(loc)
            case ElementExpEnum.TEXT.value:
                return page.get_by_text(loc, exact=True)
            case ElementExpEnum.PLACEHOLDER.value:
                return page.get_by_placeholder(loc)
            case _:
                raise MangoAutomationError(*ERROR_MSG_0020)



# -*- coding: utf-8 -*-
# @Project: 芒果测试平台
# @Description: # @Time   : 2023-04-26 22:25
# @Author : 毛鹏

from playwright.sync_api import Locator, expect as exp

from mangotools.decorator import sync_method_callback
from mangotools.exceptions.error_msg import ERROR_MSG_0021
from mangotools.models import MethodModel
from ....exceptions import MangoAutomationError
from ....tools import Meta
from ....uidrive._base_data import BaseData


class SyncWebAssertion(metaclass=Meta):
    """元素断言"""

    def __init__(self, base_data: BaseData):
        self.base_data = base_data

    @sync_method_callback('ass_web', '元素断言', 0, [
        MethodModel(f='actual'),
        MethodModel(f='expect', p='请输入元素个数', d=True)])
    def w_to_have_count(self, actual: Locator, expect: str):
        """元素是几个"""
        try:
            exp(actual).to_have_count(int(expect))
        except AssertionError as e:
            raise AssertionError(f'实际={actual.count()}, 预期={expect}') from e
        return f'实际={actual.count()}, 预期={expect}'

    @sync_method_callback('ass_web', '元素断言', 1, [MethodModel(f='actual')])
    def w_all_not_to_be_empty(self, actual: Locator):
        """元素存在"""
        count = actual.count()
        if count == 0:
            assert False, f'实际={count}, 预期>0'
        return f'实际={count}, 预期>0'

    @sync_method_callback('ass_web', '元素断言', 1, [
        MethodModel(f='actual'),
        MethodModel(f='expect', p='请输入元素存输入1，不存输入0', d=True)])
    def w_to_element_count(self, actual: Locator, expect: int):
        """元素存在个数"""
        if int(expect) == 0:
            assert actual is None, f'实际={actual}, 预期={expect}'
            return f'实际={actual}, 预期={expect}'
        else:
            if actual:
                try:
                    exp(actual).to_have_count(int(expect))
                    return f'实际={actual.count()}, 预期={expect}'
                except AssertionError as e:
                    raise AssertionError(f'实际={actual.count()}, 预期={expect}') from e
            else:
                raise MangoAutomationError(*ERROR_MSG_0021)

    @sync_method_callback('ass_web', '元素断言', 2, [
        MethodModel(f='actual'),
        MethodModel(f='expect', p='请输入不包含的文本', d=True)])
    def w_not_to_contain_text(self, actual: Locator, expect: str):
        """元素不包含文本"""
        try:
            exp(actual).not_to_contain_text(expect)
        except AssertionError as e:
            raise AssertionError(f'实际={actual}, 预期={expect}') from e
        return f'实际={actual}, 预期={expect}'

    @sync_method_callback('ass_web', '元素断言', 3, [MethodModel(f='actual')])
    def w_not_to_be_empty(self, actual: Locator):
        """元素不为空"""
        try:
            exp(actual).not_to_be_empty()
        except AssertionError as e:
            raise AssertionError(f'实际={actual}, 预期=不为空') from e
        return f'实际={actual}, 预期=不为空'

    @sync_method_callback('ass_web', '元素断言', 4, [MethodModel(f='actual')])
    def w_not_to_be_enabled(self, actual: Locator):
        """元素不启用"""
        try:
            exp(actual).not_to_be_enabled()
        except AssertionError as e:
            raise AssertionError(f'实际={actual}, 预期=不启用') from e
        return f'实际={actual}, 预期=不启用'

    @sync_method_callback('ass_web', '元素断言', 5, [MethodModel(f='actual')])
    def w_not_to_be_focused(self, actual: Locator):
        """元素不聚焦"""
        try:
            exp(actual).not_to_be_focused()
        except AssertionError as e:
            raise AssertionError(f'实际={actual}, 预期=不聚焦') from e
        return f'实际={actual}, 预期=不聚焦'

    @sync_method_callback('ass_web', '元素断言', 6, [MethodModel(f='actual')])
    def w_not_to_be_hidden(self, actual: Locator):
        """元素不可隐藏"""
        try:
            exp(actual).not_to_be_hidden()
        except AssertionError as e:
            raise AssertionError(f'实际={actual}, 预期=不可隐藏') from e
        return f'实际={actual}, 预期=不可隐藏'

    @sync_method_callback('ass_web', '元素断言', 7, [MethodModel(f='actual')])
    def w_not_to_be_in_viewport(self, actual: Locator):
        """元素不在视窗中"""
        try:
            exp(actual).not_to_be_in_viewport()
        except AssertionError as e:
            raise AssertionError(f'实际={actual}, 预期=不在视窗中') from e
        return f'实际={actual}, 预期=不在视窗中'

    @sync_method_callback('ass_web', '元素断言', 8, [MethodModel(f='actual')])
    def w_not_to_be_visible(self, actual: Locator):
        """元素不可见"""
        try:
            exp(actual).not_to_be_visible()
        except AssertionError as e:
            raise AssertionError(f'实际={actual}, 预期=不可见') from e
        return f'实际={actual}, 预期=不可见'

    @sync_method_callback('ass_web', '元素断言', 9, [
        MethodModel(f='actual'),
        MethodModel(f='expect', p='请输入样式', d=True)])
    def w_not_to_have_class(self, actual: Locator, expect: str):
        """元素没有阶级"""
        try:
            exp(actual).not_to_have_class(expect)
        except AssertionError as e:
            raise AssertionError(f'实际={actual}, 预期=没有阶级') from e
        return f'实际={actual}, 预期=没有阶级'

    @sync_method_callback('ass_web', '元素断言', 10, [MethodModel(f='actual')])
    def w_to_be_checked(self, actual: Locator):
        """复选框已选中"""
        try:
            exp(actual).to_be_checked()
        except AssertionError as e:
            raise AssertionError(f'实际={actual}, 预期=复选框已选中') from e
        return f'实际={actual}, 预期=复选框已选中'

    @sync_method_callback('ass_web', '元素断言', 11, [MethodModel(f='actual')])
    def w_to_be_disabled(self, actual: Locator):
        """元素已禁用"""
        try:
            exp(actual).to_be_disabled()
        except AssertionError as e:
            raise AssertionError(f'实际={actual}, 预期=已禁用') from e
        return f'实际={actual}, 预期=已禁用'

    @sync_method_callback('ass_web', '元素断言', 12, [MethodModel(f='actual')])
    def w_not_to_be_editable(self, actual: Locator):
        """元素已启用"""
        try:
            exp(actual).to_be_editable()
        except AssertionError as e:
            raise AssertionError(f'实际={actual}, 预期=已启用') from e
        return f'实际={actual}, 预期=已启用'

    @sync_method_callback('ass_web', '元素断言', 13, [MethodModel(f='actual')])
    def w_to_be_empty(self, actual: Locator | list | None):
        """元素为空"""
        if actual is None:
            assert True, f'实际={actual}, 预期=为空'
            return f'实际={actual}, 预期=为空'

        else:
            try:
                exp(actual).to_be_empty()
                return f'实际={actual}, 预期=为空'
            except AssertionError as e:
                raise AssertionError(f'实际={actual}, 预期=为空') from e

    @sync_method_callback('ass_web', '元素断言', 14, [MethodModel(f='actual')])
    def w_to_be_visible(self, actual: Locator):
        """元素可见"""
        try:
            exp(actual).to_be_visible()
        except AssertionError as e:
            raise AssertionError(f'实际={actual}, 预期=可见') from e
        return f'实际={actual}, 预期=可见'

    # @staticmethod
    # def w_not_to_have_actuals(actual: Locator, actuals: list):
    #     """选择已选择选项"""
    #     exp(actual).to_have_actuals(actuals)

    # @staticmethod
    # def w_not_to_have_attribute(locating: Locator, name: str, actual: str):
    #     """元素不具有属性"""
    #     exp(locating).not_to_have_attribute(name, actual)
    # @staticmethod

    # @staticmethod
    # def w_not_to_have_css(locating: Locator, name: str, actual: str):
    #     """元素不使用CSS"""
    #     exp(locating).not_to_have_css(name, actual)

    # @staticmethod
    # def w_not_to_have_id(locating: Locator, _id: str):
    #     """元素没有ID"""
    #     exp(locating).not_to_have_id(_id)
    #
    # @staticmethod
    # def w_not_to_have_js_property(locating: Locator, name: str, actual):
    #     """元素不具有js属性"""
    #     exp(locating).not_to_have_js_property(name, actual)
    #
    # @staticmethod
    # def w_not_to_have_text(locating: Locator, expected: str):
    #     """元素没有文本"""
    #     exp(locating).not_to_have_text(expected)

    # @staticmethod
    # def w_not_to_have_actual(locating: Locator, actual: str):
    #     """元素无价值"""
    #     exp(locating).not_to_have_actual(actual)

    #
    # def w_to_be_attached(self, hidden_text: str):
    #     """待连接"""
    #     exp(self.page.get_by_text(hidden_text)).to_be_attached()

    #
    # def w_to_be_editable(self, hidden_text: str):
    #     """可编辑"""
    #     locator = self.page.get_by_role("textbox")
    #     exp(locator).to_be_editable()

    # def w_to_be_enabled(self, hidden_text: str):
    #     """为空"""
    #     locator = self.page.locator("button.submit")
    #     exp(locator).to_be_enabled()

    # def w_to_be_focused(self, hidden_text: str):
    #     """聚焦"""
    #     locator = self.page.get_by_role("textbox")
    #     exp(locator).to_be_focused()
    #
    # def w_to_be_hidden(self, hidden_text: str):
    #     """隐藏"""
    #     locator = self.page.locator('.my-element')
    #     exp(locator).to_be_hidden()
    #
    # def w_to_be_in_viewport(self, hidden_text: str):
    #     """待在视口中"""
    #     locator = self.page.get_by_role("button")
    #     # Make sure at least some part of element intersects viewport.
    #     exp(locator).to_be_in_viewport()
    #     # Make sure element is fully outside of viewport.
    #     exp(locator).not_to_be_in_viewport()
    #     # Make sure that at least half of the element intersects viewport.
    #     exp(locator).to_be_in_viewport(ratio=0.5)
    #

    # def w_to_contain_text(self, hidden_text: str):
    #     """包含文本"""
    #     locator = self.page.locator('.title')
    #     exp(locator).to_contain_text("substring")
    #     exp(locator).to_contain_text(re.compile(r"\d messages"))
    #
    # def w_to_have_attribute(self, hidden_text: str):
    #     """具有属性"""
    #     locator = self.page.locator("input")
    #     exp(locator).to_have_attribute("type", "text")
    #
    # def w_to_have_class(self, hidden_text: str):
    #     """到保存类别"""
    #     locator = self.page.locator("#component")
    #     exp(locator).to_have_class(re.compile(r"selected"))
    #     exp(locator).to_have_class("selected row")
    #
    # def w_to_have_count(self, hidden_text: str):
    #     """有计数"""
    #     locator = self.page.locator("list > .component")
    #     exp(locator).to_have_count(3)
    #
    # def w_to_have_css(self, hidden_text: str):
    #     """使用CSS"""
    #     locator = self.page.get_by_role("button")
    #     exp(locator).to_have_css("display", "flex")
    #
    # def w_to_have_id(self, hidden_text: str):
    #     """到id"""
    #     locator = self.page.get_by_role("textbox")
    #     exp(locator).to_have_id("lastname")
    #
    # def w_to_have_js_property(self, hidden_text: str):
    #     """拥有js属性"""
    #     locator = self.page.locator(".component")
    #     exp(locator).to_have_js_property("loaded", True)
    #
    # def w_to_have_text(self, hidden_text: str):
    #     """有文本"""
    #     locator = self.page.locator(".title")
    #     exp(locator).to_have_text(re.compile(r"Welcome, Test User"))
    #     exp(locator).to_have_text(re.compile(r"Welcome, .*"))
    #
    # def w_to_have_actual(self, hidden_text: str):
    #     """有价值"""
    #     locator = self.page.locator("input[type=number]")
    #     exp(locator).to_have_actual(re.compile(r"[0-9]"))



# -*- coding: utf-8 -*-
# @Project: 芒果测试平台
# @Description:
# @Time   : 2023-07-07 10:14
# @Author : 毛鹏
import sys

from ._exceptions import MangoAutomationError

python_version = sys.version_info
if f"{python_version.major}.{python_version.minor}" != "3.10":
    raise Exception("必须使用>Python3.10.4")

__all__ = ['MangoAutomationError']



# -*- coding: utf-8 -*-
# @Project: 芒果测试平台
# @Description: 
# @Time   : 2024-08-13 14:07
# @Author : 毛鹏
from ...uidrive._base_data import BaseData


class PlaywrightCustomization(BaseData):
    """定制开发"""



# -*- coding: utf-8 -*-
# @Project: 芒果测试平台
# @Description: 
# @Time   : 2025-05-03 10:02
# @Author : 毛鹏
import traceback


#
# driver_object = DriverObject()
# driver_object.set_android('ed789e3b')
# test_data = DataProcessor()
# base_data = BaseData(test_data)
# base_data.android = driver_object.android.new_android()
# android_driver = AndroidDriver(base_data)
# android_driver.a_close_app('aaasdsadawdwadwa')
#


def a_ass(a, b):
    assert a == b, f'断言A=B失败, a的值:{a}, b的值:{b}'


try:
    a_ass(1, 2)
except AssertionError as error:
    print(error.args[1])
    print(type(error))
    traceback.print_exc()



# -*- coding: utf-8 -*-
# @Project: 芒果测试平台
# @Description: 
# @Time   : 2025-04-15 11:54
# @Author : 毛鹏
import sys

from ..tools._mate import Meta
from ..tools._uiautodev import start_uiautodev, stop_uiautodev

python_version = sys.version_info
if f"{python_version.major}.{python_version.minor}" != "3.10":
    raise Exception("必须使用>Python3.10.4")
__all__ = ['Meta', 'start_uiautodev', 'stop_uiautodev']
